### 0.2.2   - Nov 10, 2015
* Add lots of test cases
* Document wording

### 0.2.1   - July 15, 2015
* Add SensorSchedule to wait external task to finish lazily.
* Add WebUI screenshots.
* Lots of bug fixes.

### 0.2.0   - July 7, 2015
* Add WebUI and daemon.
* Lots of bug fixes and refactor.

### 0.1.4   - May 10, 2015
* Add English README

### 0.1.3   - April 20, 2015
* All codes are conform to PEP8 style.
* Add @luigi.multiple_text_files decorator

### 0.1.2   - April 20, 2015
* Project is more solid, add services such as travis, etc.

### 0.1.0   - March 24, 2015
* Stable version, compact with luigi==1.0.19 and snakebite==1.3.8,
  is already validated in a production environment.
